@@ -3,9 +3,9 @@
 ## 1. user defined number of lines per page
 ## 2. all lines have the same height
 ## 3. header always reprinted on all pages
-## 4. "Label-rows", ie content rows above break in the nesting structure, optionaly reprinted (default TRUE)
+## 4. "Label-rows", i.e. content rows above break in the nesting structure, optionaly reprinted (default TRUE)
 ## 5. Never (?) break on a "label"/content row
-## 6. Never (?) break on the second (ie after the first) data row at a particular leaf Elementary table.
+## 6. Never (?) break on the second (i.e. after the first) data row at a particular leaf Elementary table.
 ##
 ## Current behavior: paginate_ttree takes a TableTree object and
 ## returns a list of rtable (S3) objects for printing.
@@ -440,7 +440,7 @@ setMethod("inner_col_df", "LayoutColTree",
 
 
 
-## THIS INCLUDES BOTH "table stub" (ie column label and top_left) AND
+## THIS INCLUDES BOTH "table stub" (i.e. column label and top_left) AND
 ## title/subtitle!!!!!
 .header_rep_nlines <- function(tt, colwidths, max_width, verbose = FALSE) {
     cinfo_lines <- nlines(col_info(tt), colwidths = colwidths, max_width = max_width)
@@ -479,7 +479,7 @@ setMethod("inner_col_df", "LayoutColTree",
 }
 
 
-#' Pagination of a TableTree
+#' Pagination of a `TableTree`
 #'
 #'
 #' Paginate  an  `rtables` table  in  the  vertical and/or  horizontal
@@ -648,16 +648,13 @@ pag_btw_kids <- function(tt) {
     })
 }
 
-
-do_force_paginate <- function(tt,
-                              force_pag = vapply(tree_children(tt), has_force_pag, NA),
-                              verbose = FALSE) {
-
-
+force_paginate <- function(tt,
+                   force_pag = vapply(tree_children(tt), has_force_pag, NA),
+                   verbose = FALSE) {
     ## forced pagination is happening at this
     if(has_force_pag(tt)) {
         ret <- pag_btw_kids(tt)
-        return(lapply(ret, do_force_paginate))
+        return(unlist(lapply(ret, force_paginate)))
 
     }
     chunks <- list()
@@ -668,7 +665,7 @@ do_force_paginate <- function(tt,
                                           tt,
                                           NULL)
 
-            chunks <- c(chunks, do_force_paginate(outertbl))
+            chunks <- c(chunks, force_paginate(outertbl))
             kinds <- kinds[-1]
         } else {
             tmptbl <- tt
@@ -679,17 +676,19 @@ do_force_paginate <- function(tt,
             kinds <- kinds[-useinds]
         }
     }
-    chunks
+    unlist(chunks, recursive = TRUE)
 }
 
-
+#' @importFrom formatters do_forced_paginate
+setMethod("do_forced_paginate", "VTableTree",
+          function(obj) force_paginate(obj))
 
 non_null_na <- function(x) !is.null(x) && is.na(x)
 
 #' @export
 #' @aliases paginate_table
 #' @param cpp numeric(1) or NULL. Width (in characters) of the pages for
-#' horizontal pagination. `NA` (the default) indicates cpp should be inferred from
+#' horizontal pagination. `NA` (the default) indicates `cpp` should be inferred from
 #' the page size; `NULL` indicates no horizontal pagination should be done
 #' regardless of page size.
 #' @rdname paginate
@@ -759,11 +758,11 @@ paginate_table <- function(tt,
 
     force_pag <- vapply(tree_children(tt), has_force_pag, TRUE)
     if(has_force_pag(tt) || any(force_pag)) {
-        spltabs <- do_force_paginate(tt, verbose = verbose)
+        spltabs <- do_forced_paginate(tt)
         spltabs <- unlist(spltabs, recursive = TRUE)
         ret <- lapply(spltabs, paginate_table,
                       lpp = lpp,
-                      cpp = NULL,
+                      cpp = cpp,
                       min_siblings = min_siblings,
                       nosplitin = nosplitin,
                       colwidths = colwidths,
