@@ -9,7 +9,7 @@ test_that("column spanning works", {
         rrow("B", c(23, .4), c(43, .5), rcell(256, format = "xx")),
         rrow(),
     rrow("this is a very long section header"),
-    rrow("estimate", rcell(55.23, "xx.xx", colspan = 2), rcell(12, format="xx")),
+    rrow("estimate", rcell(55.23, "xx.xx", colspan = 2), rcell(12, format = "xx")),
     rrow("95% CI", indent = 1, rcell(c(44.8, 67.4), format = "(xx.x, xx.x)", colspan = 2), rcell(17, format = "xx")))
 
 
@@ -24,10 +24,14 @@ test_that("column spanning works", {
 
     spanned_values(cirow) <- list(rcell(c(7, 15)), rcell(c(7, 15)), rcell(13, format = "xx"))
 
-    expect_error({spanned_values(cirow) <- list(5, 7, 10)}, "Got more than one unique")
+    expect_error({
+        spanned_values(cirow) <- list(5, 7, 10)
+    },
+    "Got more than one unique")
 
     mylrow <- rrow("hiya!!!")
 
-    expect_error({spanned_values(mylrow) <- list(5)}, "Label rows can't have non-null")
-
+    expect_error({
+        spanned_values(mylrow) <- list(5)
+    }, "Label rows can't have non-null")
 })
